*****************************************
Protean: The Clean Architecture Framework
*****************************************

.. image:: https://readthedocs.org/projects/protean/badge/?style=flat
    :target: https://readthedocs.org/projects/protean
.. image:: https://img.shields.io/pypi/l/protean.svg
    :target: https://pypi.org/project/protean/
.. image:: https://img.shields.io/pypi/v/protean.svg
    :target: https://pypi.org/project/protean/
.. image:: https://img.shields.io/pypi/wheel/protean.svg
    :target: https://pypi.org/project/protean/
.. image:: https://img.shields.io/pypi/pyversions/protean.svg
    :target: https://pypi.org/project/protean/
.. image:: https://img.shields.io/pypi/implementation/protean.svg
    :target: https://pypi.org/project/protean/
.. image:: https://api.codacy.com/project/badge/Grade/826792451bd94ec6a8b46a3887443e93
    :target: https://www.codacy.com/app/subhashb/protean?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=proteanhq/protean&amp;utm_campaign=Badge_Grade
.. image:: https://codecov.io/gh/proteanhq/protean/branch/master/graph/badge.svg
    :target: https://codecov.io/gh/proteanhq/protean

Installation
############

::

    pip install protean

Read the Docs
#############

Online docs are available at: https://protean.readthedocs.io/en/latest/

Development
###########

::

    pyenv virtualenv -p python3.6 3.6.5 protean-dev

To run the all tests run::

    tox
